autowisp.database.data_model.provenance.mount_type module — AutoWISP documentation

# autowisp.database.data_model.provenance.mount_type module

## Class Inheritance Diagram

Define the mount type dataset table for the pipeline

class autowisp.database.data_model.provenance.mount_type.MountType(**kwargs)

  Bases: `DataModelBase`

  The table describing the different mount types

  id

    A unique identifier for each row.

  make

    The make of the mount type

  model

    The model for each mount type

  mounts
  notes

    The notes provided for the mount type

  timestamp

    When record was last changed

  version

    The version of the mount type